==> jtreg_4.2-b10.orig.tar.gz: jtreg-jtreg4.2-b10/src/share/classes/com/sun/javatest/regtest/config/RegressionEnvironment.java <==
/*
 * Copyright (c) 2005, 2016, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package com.sun.javatest.regtest.config;

import java.util.Map;

import com.sun.javatest.TestEnvironment;

public class RegressionEnvironment extends TestEnvironment
{
    RegressionEnvironment(RegressionParameters params) throws Fault {
        super("regtest", new Map<?, ?>[] { }, new String[] { });
        this.params = params;
    }

    private RegressionEnvironment(RegressionEnvironment other) {
        super(other);
        this.params = other.params;
    }

    @Override
    public TestEnvironment copy() {
        return new RegressionEnvironment(this);
    }

    public final RegressionParameters params;
}

==> jtreg_5.1-b01.orig.tar.gz: jtreg-jtreg5.1-b01/src/share/classes/com/sun/javatest/regtest/config/RegressionEnvironment.java <==
/*
 * Copyright (c) 2005, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package com.sun.javatest.regtest.config;

import java.util.ArrayList;
import java.util.Map;

import com.sun.javatest.TestEnvironment;

public class RegressionEnvironment extends TestEnvironment
{
    RegressionEnvironment(RegressionParameters params) throws Fault {
        super("regtest", new ArrayList<Map<String, String>>(), new String[] { });
        this.params = params;
    }

    private RegressionEnvironment(RegressionEnvironment other) {
        super(other);
        this.params = other.params;
    }

    @Override
    public TestEnvironment copy() {
        return new RegressionEnvironment(this);
    }

    public final RegressionParameters params;
}
